==> kap-0.6.1.tar.gz: kap-0.6.1/setup.py <==
#!/usr/bin/env python
#******************************************************************************
#**** Copyright (C) 2009, 2010                                             ****
#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
#****                                                                      ****
#**** This program is free software: you can redistribute it and/or modify ****
#**** it under the terms of the GNU General Public License as published by ****
#**** the Free Software Foundation, either version 3 of the License, or    ****
#**** (at your option) any later version.                                  ****
#****                                                                      ****
#**** This program is distributed in the hope that it will be useful,      ****
#**** but WITHOUT ANY WARRANTY; without even the implied warranty of       ****
#**** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        ****
#**** GNU General Public License for more details.                         ****
#****                                                                      ****
#**** You should have received a copy of the GNU General Public License    ****
#**** along with this program.  If not, see <http://www.gnu.org/licenses/> ****
#******************************************************************************

from distutils.core import setup


# Basic package setup information
setup(  name='kap',
        version='0.6.1',
        description='A player with a search-able media library',
        long_description='Karaoke Audio-video Player is a media player with for KJs at their shows.',
        author='John Schneiderman',
        author_email='JohnMS@member.fsf.org',
        url='http://kap.nongnu.org',
        license='GPLv3+',
        platforms=  [
                        'GNU/Linux',
                        'POSIX',
                        'Mac OS',
                        'Windows'
                    ],
        classifiers=[
                        'Development Status :: 4 - Beta',
                        'Environment :: MacOS X',
                        'Environment :: Win32 (MS Windows)',
                        'Environment :: X11 Applications :: GTK',
                        'Intended Audience :: End Users/Desktop',
                        'License :: OSI Approved :: GNU General Public License (GPL)',
                        'Natural Language :: English',
                        'Operating System :: MacOS',
                        'Operating System :: Microsoft :: Windows',
                        'Operating System :: POSIX :: Linux',
                        'Programming Language :: Python :: 2.5',
                        'Topic :: Multimedia :: Sound/Audio :: Players'
                    ],
        data_files= [
                        (
                            'bin',
                            [
                                'data/kap'
                            ]
                        ),
                        (
                            'share/applications',
                            [
                                'data/kap.desktop'
                            ]
                        ),
                        (
                            'share/icons/hicolor/48x48/apps',
                            [
                                'data/kap.png',
                            ]
                        ),
                        (
                            'share/kap',
                            [
                                'data/bottom.png',
                                'data/next.png',
                                'data/play.png',
                                'data/remove.png',
                                'data/stop.png',
                                'data/unmute.png',
                                'data/down.png',
                                'data/mute.png',
                                'data/pause.png',
                                'data/prev.png',
                                'data/restart.png',
                                'data/top.png',
                                'data/up.png'
                            ]
                        )
                    ],
        packages=['kap']
    )

==> kap-0.7.0.tar.gz: kap-0.7.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#******************************************************************************
#**** Copyright (C) 2009, 2010                                             ****
#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
#****                                                                      ****
#**** This program is free software: you can redistribute it and/or modify ****
#**** it under the terms of the GNU General Public License as published by ****
#**** the Free Software Foundation, either version 3 of the License, or    ****
#**** (at your option) any later version.                                  ****
#****                                                                      ****
#**** This program is distributed in the hope that it will be useful,      ****
#**** but WITHOUT ANY WARRANTY; without even the implied warranty of       ****
#**** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        ****
#**** GNU General Public License for more details.                         ****
#****                                                                      ****
#**** You should have received a copy of the GNU General Public License    ****
#**** along with this program.  If not, see <http://www.gnu.org/licenses/> ****
#******************************************************************************

from distutils.core import setup


# Basic package setup information
setup(  name='kap',
        version='0.7.0',
        description='A player with a search-able media library',
        long_description='Karaoke Audio-video Player is a media player designed for KJs at their shows.',
        author='John Schneiderman',
        author_email='JohnMS@member.fsf.org',
        url='http://kap.nongnu.org',
        license='GPLv3+',
        platforms=  [
                        'GNU/Linux',
                        'POSIX',
                        'Mac OS',
                        'Windows'
                    ],
        classifiers=[
                        'Development Status :: 4 - Beta',
                        'Environment :: MacOS X',
                        'Environment :: Win32 (MS Windows)',
                        'Environment :: X11 Applications :: GTK',
                        'Intended Audience :: End Users/Desktop',
                        'License :: OSI Approved :: GNU General Public License (GPL)',
                        'Natural Language :: English',
                        'Operating System :: MacOS',
                        'Operating System :: Microsoft :: Windows',
                        'Operating System :: POSIX :: Linux',
                        'Programming Language :: Python :: 2.5',
                        'Topic :: Multimedia :: Sound/Audio :: Players'
                    ],
        data_files= [
                        (
                            'bin',
                            [
                                'data/kap'
                            ]
                        ),
                        (
                            'share/applications',
                            [
                                'data/kap.desktop'
                            ]
                        ),
                        (
                            'share/icons/hicolor/48x48/apps',
                            [
                                'data/kap.png',
                            ]
                        ),
                        (
                            'share/kap',
                            [
                                'data/bottom.png',
                                'data/next.png',
                                'data/play.png',
                                'data/remove.png',
                                'data/stop.png',
                                'data/unmute.png',
                                'data/down.png',
                                'data/mute.png',
                                'data/pause.png',
                                'data/prev.png',
                                'data/restart.png',
                                'data/top.png',
                                'data/up.png'
                            ]
                        )
                    ],
        package_dir = {'KaraokeAudiovideoPlayer': 'src'},
        packages=['KaraokeAudiovideoPlayer']
    )
